Changelog
=========

`2.0a2`_
------

New features
~~~~~~~~~~~~

* Configurable sync strategies
* Management commands for ldap import
* Mass import of users and groups
* Sync LDAP users and groups on login

Bugfixes
~~~~~~~~

* None

Minor changes
~~~~~~~~~~~~~

* None

_`2.0a2`: https://edugit.org/AlekSIS/official/AlekSIS-App-LDAP/AlekSIS-App-LDAP/-/tags/2.0a2
